@@ -1,7 +1,7 @@
 /*
  * ExampleSnooping.java
  *
- * Copyright (c) 2008 Operational Dynamics Consulting Pty Ltd
+ * Copyright (c) 2008-2009 Operational Dynamics Consulting Pty Ltd
  *
  * The code in this file, and the program it is a part of, are made available
  * to you by the authors under the terms of the "GNU General Public Licence,
@@ -39,7 +39,7 @@ public class ExampleSnooping
 
         w.add(l);
 
-        w.connect(new Widget.KEY_PRESS_EVENT() {
+        w.connect(new Widget.KeyPressEvent() {
             public boolean onKeyPressEvent(Widget source, EventKey event) {
                 final Keyval key;
                 final ModifierType mod;
@@ -69,7 +69,7 @@ public class ExampleSnooping
         w.setBorderWidth(30);
         w.showAll();
 
-        w.connect(new Window.DELETE_EVENT() {
+        w.connect(new Window.DeleteEvent() {
             public boolean onDeleteEvent(Widget source, Event event) {
                 Gtk.mainQuit();
                 return false;
@@ -78,8 +78,8 @@ public class ExampleSnooping
     }
 
     public static void main(String[] args) {
-        Gtk.init(args);
         Glib.setProgramName("snooping");
+        Gtk.init(args);
 
         new ExampleSnooping();
 
